Sandbox
=======

Runs custom application logic in a sandbox.

.. py:module:: vumi.application.sandbox


Sandbox application workers
---------------------------


Sandbox
^^^^^^^

.. autoclass:: SandboxConfig

.. autoclass:: Sandbox


Javascript Sandbox
^^^^^^^^^^^^^^^^^^

.. autoclass:: JsSandboxConfig

.. autoclass:: JsSandbox


Javascript File Sandbox
^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: JsFileSandbox
   :members:
       CONFIG_CLASS


Sandbox resources
-----------------


RedisResource
^^^^^^^^^^^^^

.. autoclass:: RedisResource
   :members:


OutboundResource
^^^^^^^^^^^^^^^^

.. autoclass:: OutboundResource


JsSandboxResource
^^^^^^^^^^^^^^^^^

.. autoclass:: JsSandboxResource


LoggingResource
^^^^^^^^^^^^^^^

.. autoclass:: LoggingResource
   :members:


HttpClientResource
^^^^^^^^^^^^^^^^^^

.. autoclass:: HttpClientResource
   :members:
